@@ -2,6 +2,7 @@ use crate::policy;
 
 #[derive(PartialEq)]
 enum Value {
+    None,
     Neutral,
     Pass,
     Fail,
@@ -10,13 +11,14 @@ enum Value {
 /// Result of applying a DMARC policy
 pub struct DMARCResult {
     value: Value,
-    policy: policy::Policy,
+    policy: Option<policy::Policy>,
 }
 
 impl DMARCResult {
     /// Get the result as string (neutral, fail or pass)
     pub fn to_str(&self) -> &'static str {
         match self.value {
+            Value::None => "none",
             Value::Neutral => "neutral",
             Value::Pass => "pass",
             Value::Fail => "fail",
@@ -24,32 +26,44 @@ impl DMARCResult {
     }
 
     /// Constructs a neutral result
-    pub(crate) fn neutral(policy: policy::Policy) -> Self {
+    pub fn neutral(policy: policy::Policy) -> Self {
         Self {
             value: Value::Neutral,
-            policy,
+            policy: Some(policy),
         }
     }
 
     /// Constructs a pass result
-    pub(crate) fn pass(policy: policy::Policy) -> Self {
+    pub fn pass(policy: policy::Policy) -> Self {
         Self {
             value: Value::Pass,
-            policy,
+            policy: Some(policy),
         }
     }
 
     /// Constructs a fail result
-    pub(crate) fn fail(policy: policy::Policy) -> Self {
+    pub fn fail(policy: policy::Policy) -> Self {
         Self {
             value: Value::Fail,
-            policy,
+            policy: Some(policy),
+        }
+    }
+
+    /// Constructs a none result
+    pub fn none() -> Self {
+        Self {
+            value: Value::None,
+            policy: None,
         }
     }
 
     /// Checks if the email is supposed to be reject based on the DMARC policy and
     /// its result
     pub fn should_reject(&self) -> bool {
-        self.value == Value::Fail && self.policy.action == policy::ReceiverAction::Reject
+        if let Some(policy) = &self.policy {
+            self.value == Value::Fail && policy.action == policy::ReceiverAction::Reject
+        } else {
+            false
+        }
     }
 }
